@@ -862,12 +862,12 @@ display_system_info_common (bmc_info_state_data_t *state_data,
                     obj_cmd_rs) < 0)
         {
           if ((ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_COMMAND_INVALID_OR_UNSUPPORTED
-	       && (ipmi_check_completion_code (obj_cmd_first_set_rs,
+	       && (ipmi_check_completion_code (obj_cmd_rs,
 					       IPMI_COMP_CODE_INVALID_COMMAND) == 1
-		   || ipmi_check_completion_code (obj_cmd_first_set_rs,
+		   || ipmi_check_completion_code (obj_cmd_rs,
 						  IPMI_COMP_CODE_INVALID_DATA_FIELD_IN_REQUEST) == 1))
 	      || (ipmi_ctx_errnum (state_data->ipmi_ctx) == IPMI_ERR_BAD_COMPLETION_CODE
-		  && ipmi_check_completion_code (obj_cmd_first_set_rs,
+		  && ipmi_check_completion_code (obj_cmd_rs,
 						 IPMI_COMP_CODE_GET_SYSTEM_INFO_PARAMETERS_PARAMETER_NOT_SUPPORTED) == 1))
             {
               rv = 0;
