@@ -171,7 +171,9 @@ extern "C" {
 #define IPMI_FRU_LANGUAGE_CODE_SWEDISH              112
 #define IPMI_FRU_LANGUAGE_CODE_SWAHILI              113
 #define IPMI_FRU_LANGUAGE_CODE_TAMIL                114
-#define IPMI_FRU_LANGUAGE_CODE_TEGULU               115
+#define IPMI_FRU_LANGUAGE_CODE_TELUGU               115
+/* Spec has "Tegulu", likely a typo */
+#define IPMI_FRU_LANGUAGE_CODE_TEGULU               IPMI_FRU_LANGUAGE_CODE_TELUGU
 #define IPMI_FRU_LANGUAGE_CODE_TAJIK                116
 #define IPMI_FRU_LANGUAGE_CODE_THAI                 117
 #define IPMI_FRU_LANGUAGE_CODE_TIGRINYA             118
